@@ -17,9 +17,12 @@ from .xpack import XPackClient
 from .utils import query_params, _make_path, SKIP_IN_PATH, _bulk_body
 
 # xpack APIs
+from .async_search import AsyncSearchClient
+from .autoscaling import AutoscalingClient
 from .ccr import CcrClient
 from .data_frame import Data_FrameClient
 from .deprecation import DeprecationClient
+from .eql import EqlClient
 from .graph import GraphClient
 from .ilm import IlmClient
 from .license import LicenseClient
@@ -36,13 +39,13 @@ from .slm import SlmClient
 from .transform import TransformClient
 
 
-logger = logging.getLogger("elasticsearch7")
+logger = logging.getLogger("elasticsearch")
 
 
 def _normalize_hosts(hosts):
     """
     Helper function to transform hosts argument to
-    :class:`~elasticsearch7.Elasticsearch` to a list of dicts.
+    :class:`~elasticsearch.Elasticsearch` to a list of dicts.
     """
     # if hosts are empty, just defer to defaults down the line
     if hosts is None:
@@ -91,13 +94,13 @@ class Elasticsearch(object):
 
     The instance has attributes ``cat``, ``cluster``, ``indices``, ``ingest``,
     ``nodes``, ``snapshot`` and ``tasks`` that provide access to instances of
-    :class:`~elasticsearch7.client.CatClient`,
-    :class:`~elasticsearchelasticsearch7.client.ClusterClient`,
-    :class:`~elasticsearch7.client.IndicesClient`,
-    :class:`~elasticsearch7.client.IngestClient`,
-    :class:`~elasticsearch7.client.NodesClient`,
-    :class:`~elasticsearch7.client.SnapshotClient` and
-    :class:`~elasticsearch7.client.TasksClient` respectively. This is the
+    :class:`~elasticsearch.client.CatClient`,
+    :class:`~elasticsearch.client.ClusterClient`,
+    :class:`~elasticsearch.client.IndicesClient`,
+    :class:`~elasticsearch.client.IngestClient`,
+    :class:`~elasticsearch.client.NodesClient`,
+    :class:`~elasticsearch.client.SnapshotClient` and
+    :class:`~elasticsearch.client.TasksClient` respectively. This is the
     preferred (and only supported) way to get access to those classes and their
     methods.
 
@@ -108,7 +111,7 @@ class Elasticsearch(object):
         es = Elasticsearch(connection_class=ThriftConnection)
 
     If you want to turn on :ref:`sniffing` you have several options (described
-    in :class:`~elasticsearch7.Transport`)::
+    in :class:`~elasticsearch.Transport`)::
 
         # create connection that will automatically inspect the cluster to get
         # the list of active nodes. Start with nodes running on 'esnode1' and
@@ -134,7 +137,7 @@ class Elasticsearch(object):
         ])
 
     If using SSL, there are several parameters that control how we deal with
-    certificates (see :class:`~elasticsearch7.Urllib3HttpConnection` for
+    certificates (see :class:`~elasticsearch.Urllib3HttpConnection` for
     detailed description of the options)::
 
         es = Elasticsearch(
@@ -148,7 +151,7 @@ class Elasticsearch(object):
         )
 
     If using SSL, but don't verify the certs, a warning message is showed
-    optionally (see :class:`~elasticsearch7.Urllib3HttpConnection` for
+    optionally (see :class:`~elasticsearch.Urllib3HttpConnection` for
     detailed description of the options)::
 
         es = Elasticsearch(
@@ -162,7 +165,7 @@ class Elasticsearch(object):
         )
 
     SSL client authentication is supported
-    (see :class:`~elasticsearch7.Urllib3HttpConnection` for
+    (see :class:`~elasticsearch.Urllib3HttpConnection` for
     detailed description of the options)::
 
         es = Elasticsearch(
@@ -191,11 +194,11 @@ class Elasticsearch(object):
         )
 
     By default, `JSONSerializer
-    <https://github.com/elastic/elasticsearch/blob/master/elasticsearch/serializer.py#L24>`_
+    <https://github.com/elastic/elasticsearch-py/blob/master/elasticsearch/serializer.py#L24>`_
     is used to encode all outgoing requests.
     However, you can implement your own custom serializer::
 
-        from elasticsearch7.serializer import JSONSerializer
+        from elasticsearch.serializer import JSONSerializer
 
         class SetEncoder(JSONSerializer):
             def default(self, obj):
@@ -213,16 +216,16 @@ class Elasticsearch(object):
         """
         :arg hosts: list of nodes, or a single node, we should connect to.
             Node should be a dictionary ({"host": "localhost", "port": 9200}),
-            the entire dictionary will be passed to the :class:`~elasticsearch7.Connection`
+            the entire dictionary will be passed to the :class:`~elasticsearch.Connection`
             class as kwargs, or a string in the format of ``host[:port]`` which will be
             translated to a dictionary automatically.  If no value is given the
-            :class:`~elasticsearch7.Connection` class defaults will be used.
+            :class:`~elasticsearch.Connection` class defaults will be used.
 
-        :arg transport_class: :class:`~elasticsearch7.Transport` subclass to use.
+        :arg transport_class: :class:`~elasticsearch.Transport` subclass to use.
 
         :arg kwargs: any additional arguments will be passed on to the
-            :class:`~elasticsearch7.Transport` class and, subsequently, to the
-            :class:`~elasticsearch7.Connection` instances.
+            :class:`~elasticsearch.Transport` class and, subsequently, to the
+            :class:`~elasticsearch.Connection` instances.
         """
         self.transport = transport_class(_normalize_hosts(hosts), **kwargs)
 
@@ -237,9 +240,12 @@ class Elasticsearch(object):
         self.tasks = TasksClient(self)
 
         self.xpack = XPackClient(self)
+        self.async_search = AsyncSearchClient(self)
+        self.autoscaling = AutoscalingClient(self)
         self.ccr = CcrClient(self)
         self.data_frame = Data_FrameClient(self)
         self.deprecation = DeprecationClient(self)
+        self.eql = EqlClient(self)
         self.graph = GraphClient(self)
         self.ilm = IlmClient(self)
         self.indices = IndicesClient(self)
@@ -274,7 +280,6 @@ class Elasticsearch(object):
         """
         Returns whether the cluster is running.
         `<https://www.elastic.co/guide/en/elasticsearch/reference/current/index.html>`_
-
         """
         try:
             return self.transport.perform_request(
@@ -288,7 +293,6 @@ class Elasticsearch(object):
         """
         Returns basic information about the cluster.
         `<https://www.elastic.co/guide/en/elasticsearch/reference/current/index.html>`_
-
         """
         return self.transport.perform_request(
             "GET", "/", params=params, headers=headers
@@ -434,8 +438,6 @@ class Elasticsearch(object):
             the returned _source field, can be overridden on each sub-request
         :arg _source_includes: Default list of fields to extract and
             return from the _source field, can be overridden on each sub-request
-        :arg doc_type: Default document type for items which don't
-            provide one
         :arg pipeline: The pipeline id to preprocess incoming documents
             with
         :arg refresh: If `true` then refresh the affected shards to make
@@ -522,7 +524,7 @@ class Elasticsearch(object):
             given in the query string
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg ignore_throttled: Whether specified concrete, expanded or
             aliased indices should be ignored when throttled
         :arg ignore_unavailable: Whether specified concrete indices
@@ -661,7 +663,7 @@ class Elasticsearch(object):
             given in the query string
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg from_: Starting offset (default: 0)
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
@@ -681,15 +683,15 @@ class Elasticsearch(object):
         :arg scroll: Specify how long a consistent view of the index
             should be maintained for scrolled search
         :arg scroll_size: Size on the scroll request powering the delete
-            by query
+            by query  Default: 100
         :arg search_timeout: Explicit timeout for each search request.
             Defaults to no timeout.
         :arg search_type: Search operation type  Valid choices:
             query_then_fetch, dfs_query_then_fetch
         :arg size: Deprecated, please use `max_docs` instead
         :arg slices: The number of slices this task should be divided
-            into. Defaults to 1 meaning the task isn't sliced into subtasks.
-            Default: 1
+            into. Defaults to 1, meaning the task isn't sliced into subtasks. Can be
+            set to `auto`.  Default: 1
         :arg sort: A comma-separated list of <field>:<direction> pairs
         :arg stats: Specific 'tag' of the request for logging and
             statistical purposes
@@ -942,7 +944,7 @@ class Elasticsearch(object):
             string or when no indices have been specified)
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg fields: A comma-separated list of field names
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
@@ -1152,8 +1154,8 @@ class Elasticsearch(object):
             the number of shards the search request expands to exceeds the
             threshold. This filter roundtrip can limit the number of shards
             significantly if for instance a shard can not match any documents based
-            on it's rewrite method ie. if date filters are mandatory to match but
-            the shard bounds and the query are disjoint.  Default: 128
+            on its rewrite method ie. if date filters are mandatory to match but the
+            shard bounds and the query are disjoint.
         :arg rest_total_hits_as_int: Indicates whether hits.total should
             be rendered as an integer or an object in the rest search response
         :arg search_type: Search operation type  Valid choices:
@@ -1293,7 +1295,6 @@ class Elasticsearch(object):
 
         :arg id: Script ID
         :arg body: The document
-        :arg context: Script context
         :arg context: Context name to compile script against
         :arg master_timeout: Specify timeout for connection to master
         :arg timeout: Explicit operation timeout
@@ -1328,7 +1329,7 @@ class Elasticsearch(object):
             string or when no indices have been specified)
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg search_type: Search operation type  Valid choices:
@@ -1372,8 +1373,8 @@ class Elasticsearch(object):
         :arg scroll: Control how long to keep the search context alive
             Default: 5m
         :arg slices: The number of slices this task should be divided
-            into. Defaults to 1 meaning the task isn't sliced into subtasks.
-            Default: 1
+            into. Defaults to 1, meaning the task isn't sliced into subtasks. Can be
+            set to `auto`.  Default: 1
         :arg timeout: Time each individual bulk request should wait for
             shards that are unavailable.  Default: 1m
         :arg wait_for_active_shards: Sets the number of shard copies
@@ -1452,12 +1453,11 @@ class Elasticsearch(object):
 
         :arg body: The scroll ID if not passed by URL or query
             parameter.
-        :arg scroll_id: The scroll ID
+        :arg scroll_id: The scroll ID for scrolled search
         :arg rest_total_hits_as_int: Indicates whether hits.total should
             be rendered as an integer or an object in the rest search response
         :arg scroll: Specify how long a consistent view of the index
             should be maintained for scrolled search
-        :arg scroll_id: The scroll ID for scrolled search
         """
         if scroll_id in SKIP_IN_PATH and body in SKIP_IN_PATH:
             raise ValueError("You need to supply scroll_id or body.")
@@ -1555,7 +1555,7 @@ class Elasticsearch(object):
             as the docvalue representation of a field for each hit
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg explain: Specify whether to return detailed information
             about score computation as part of a hit
         :arg from_: Starting offset (default: 0)
@@ -1574,8 +1574,8 @@ class Elasticsearch(object):
             the number of shards the search request expands to exceeds the
             threshold. This filter roundtrip can limit the number of shards
             significantly if for instance a shard can not match any documents based
-            on it's rewrite method ie. if date filters are mandatory to match but
-            the shard bounds and the query are disjoint.  Default: 128
+            on its rewrite method ie. if date filters are mandatory to match but the
+            shard bounds and the query are disjoint.
         :arg preference: Specify the node or shard the operation should
             be performed on (default: random)
         :arg q: Query in the Lucene query string syntax
@@ -1648,7 +1648,7 @@ class Elasticsearch(object):
             string or when no indices have been specified)
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg local: Return local information, do not retrieve the state
@@ -1696,7 +1696,7 @@ class Elasticsearch(object):
             execution  Default: true
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg explain: Specify whether to return detailed information
             about score computation as part of a hit
         :arg ignore_throttled: Whether specified concrete, expanded or
@@ -1925,7 +1925,7 @@ class Elasticsearch(object):
             given in the query string
         :arg expand_wildcards: Whether to expand wildcard expression to
             concrete indices that are open, closed or both.  Valid choices: open,
-            closed, none, all  Default: open
+            closed, hidden, none, all  Default: open
         :arg from_: Starting offset (default: 0)
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
@@ -1947,15 +1947,15 @@ class Elasticsearch(object):
         :arg scroll: Specify how long a consistent view of the index
             should be maintained for scrolled search
         :arg scroll_size: Size on the scroll request powering the update
-            by query
+            by query  Default: 100
         :arg search_timeout: Explicit timeout for each search request.
             Defaults to no timeout.
         :arg search_type: Search operation type  Valid choices:
             query_then_fetch, dfs_query_then_fetch
         :arg size: Deprecated, please use `max_docs` instead
         :arg slices: The number of slices this task should be divided
-            into. Defaults to 1 meaning the task isn't sliced into subtasks.
-            Default: 1
+            into. Defaults to 1, meaning the task isn't sliced into subtasks. Can be
+            set to `auto`.  Default: 1
         :arg sort: A comma-separated list of <field>:<direction> pairs
         :arg stats: Specific 'tag' of the request for logging and
             statistical purposes
@@ -2017,7 +2017,7 @@ class Elasticsearch(object):
     def get_script_context(self, params=None, headers=None):
         """
         Returns all script contexts.
-
+        `<https://www.elastic.co/guide/en/elasticsearch/painless/master/painless-contexts.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_script_context", params=params, headers=headers
@@ -2027,7 +2027,7 @@ class Elasticsearch(object):
     def get_script_languages(self, params=None, headers=None):
         """
         Returns available script types, languages and contexts
-
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/modules-scripting.html>`_
         """
         return self.transport.perform_request(
             "GET", "/_script_language", params=params, headers=headers
